@@ -13,8 +13,6 @@ import (
 
 	"github.com/aquasecurity/tfsec/pkg/provider"
 
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
@@ -206,7 +204,7 @@ data "aws_iam_policy_document" "kms_policy" {
 		RequiredTypes:   []string{"resource"},
 		RequiredLabels:  []string{"aws_iam_policy", "aws_iam_group_policy", "aws_iam_user_policy", "aws_iam_role_policy"},
 		DefaultSeverity: severity.High,
-		CheckFunc: func(set result.Set, resourceBlock block.Block, ctx *hclcontext.Context) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, module block.Module) {
 
 			policyAttr := resourceBlock.GetAttribute("policy")
 			if policyAttr.IsNil() {
@@ -218,7 +216,7 @@ data "aws_iam_policy_document" "kms_policy" {
 				return
 			}
 
-			policyDocumentBlock, err := ctx.GetReferencedBlock(policyAttr)
+			policyDocumentBlock, err := module.GetReferencedBlock(policyAttr)
 			if err != nil {
 				return
 			}
@@ -235,7 +233,7 @@ data "aws_iam_policy_document" "kms_policy" {
 						continue
 					}
 
-					if statementBlock.HasChild("actions") && statementBlock.GetAttribute("actions").Contains("kms:*") {
+					if statementBlock.HasChild("actions") && statementBlock.GetAttribute("actions").HasIntersect("kms:*", "kms:Decrypt") {
 						if resources := statementBlock.GetAttribute("resources"); resources.IsNotNil() {
 							resources.Each(func(key, value cty.Value) {
 								if value.Type() == cty.String && strings.Contains(value.AsString(), ("*")) {
